@@ -16,7 +16,6 @@ class CalendarEvent:
         self.onclick = onclick
         self.css = css
 
-
 class Calendar:
     def __init__(self, days, hours, events):
         self.days = days
@@ -28,11 +27,17 @@ class CalendarWeek:
         self.dates = dates
 
 class CalendarDate:
-    def __init__(self, label, content):
+    def __init__(self, label, events=None):
         self.label = label
-        self.content = content
+        self.events = [] if events is None else events
 
 class MonthlyCalendar:
     def __init__(self, days, weeks):
         self.days = days
         self.weeks = weeks
+
+class MonthlyCalendarEvent:
+    def __init__(self, label, onclick=None, css=None):
+        self.label = label
+        self.onclick = onclick
+        self.css = css
