@@ -11,9 +11,19 @@ class TableFilter:
 
 
 class TableButton:
-    def __init__(self, label, action):
+    def __init__(self, label, action=None, icon=None, style=None, enabled=None, on_click=None):
         self.label = label
         self.action = action
+        self.icon = icon
+        self.style = style
+        self.enabled = enabled
+        self.on_click = on_click
+
+
+class TableButtonIcon:
+    def __init__(self, icon, visible=None):
+        self.icon = icon
+        self.visible = visible
 
 
 class TableButtonGroup:
@@ -28,7 +38,7 @@ class TableButtonDivider:
 
 
 class TableColumn:
-    def __init__(self, key, name, type=None, value=None, method=None, link=None, sortable=False):
+    def __init__(self, key, name="", type=None, value=None, method=None, link=None, sortable=False, buttons=[]):
         self.key = key
         self.name = name
         self.type = type
@@ -36,16 +46,18 @@ class TableColumn:
         self.method = method
         self.link = link
         self.sortable = sortable
+        self.buttons = buttons
 
 
 class Table:
-    def __init__(self, model, columns, rows=None, path=None, heading=None, create=None, update=None,
+    def __init__(self, model, columns, rows=None, path=None, base=None, heading=None, create=None, update=None,
                  search=False, upload=False, filters=None, buttons=None, placeholder=None, sort='date_asc'):
         self.model = model
         self.columns = columns
         self.rows = rows
         self.count = rows.count if rows else 0
         self.path = path
+        self.base = base
         self.sort = sort
         self.title = None
         self.params = {}
@@ -100,7 +112,7 @@ class TableView(Table):
         space = self.get_space()
         self.rows = paginate(request, context, rows, space=space)
         self.count = rows.count()
-        context['base'] = settings.DEFAULT_SPACE + '/base.html'
+        context['base'] = self.base if self.base else settings.DEFAULT_SPACE + '/base.html'
         context['title'] = self.title
         context['table'] = self
 
