@@ -8,6 +8,7 @@ import smtplib
 import sys
 import uuid
 from datetime import datetime
+from email.mime.application import MIMEApplication
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 
@@ -315,17 +316,48 @@ def clean_html(raw_html):
     return cleantext
 
 
-def send_mail2(to, subject, body):
+class MailAttachment:
+    def __init__(self, name, path):
+        self.name = name
+        self.path = path
+
+    def get_buffer(self):
+        return open(self.path, 'rb').read()
+
+
+class MailAttachmentFromBuffer:
+    def __init__(self, name, buffer):
+        self.name = name
+        self.buffer = buffer
+
+    def get_buffer(self):
+        return self.buffer
+
+
+def send_mail2(to, subject, body, host=None, port=None, username=None, password=None, sender=None, attachments=None):
+    sender = sender if sender else settings.MAIL_USERNAME
+    username = username if username else settings.MAIL_USERNAME
+    password = password if password else settings.MAIL_PASSWORD
+
     msg = MIMEMultipart()
-    msg['From'] = settings.MAIL_USERNAME
+    msg['From'] = sender
     msg['To'] = to
     msg['Subject'] = subject
     msg.attach(MIMEText(body, 'html'))
 
-    server = smtplib.SMTP('smtp.gmail.com', 587)
+    if attachments:
+        for attachment in attachments:
+            part = MIMEApplication(
+                attachment.get_buffer(),
+                Name=attachment.name
+            )
+            part['Content-Disposition'] = 'attachment; filename="%s"' % attachment.name
+            msg.attach(part)
+
+    server = smtplib.SMTP(host if host else 'smtp.gmail.com', port if port else 587)
     server.starttls()
-    server.login(settings.MAIL_USERNAME, settings.MAIL_PASSWORD)
-    server.sendmail(settings.MAIL_USERNAME, to, msg.as_string())
+    server.login(username, password)
+    server.sendmail(sender, to, msg.as_string())
     server.quit()
 
 
@@ -381,7 +413,7 @@ def get_path_leaf(request, context):
     path = get_path_from_request(request)
     action = get_action(request)
     if action == 'back':
-        path = path.rsplit(':', 1)[0]
+        path = pop(path)
         action = ''
     context['back'] = path.split(':')[-1]
     context['path'] = path
@@ -394,21 +426,27 @@ def get_path(request, context, obj, prefix, space=settings.DEFAULT_SPACE):
     if 'back' in request.GET and 'path' in request.session:
         path = request.session['path']
         request.session.pop('path')
-        path = path.rsplit(':', 1)[0]
+        path = pop(path)
 
     action = get_action(request)
-    if action in ['back', 'open_item']:
-        path = path.rsplit(':', 1)[0]
+
+    if action == 'back':
+        path = pop(path)
         action = ''
     else:
+        if action == 'open_item':
+            path = pop(path)
+            action = ''
+
         if obj:
-            item = reverse(space + ':' + prefix + "_update", kwargs={'pk': obj.id})
+            segment = reverse(space + ':' + prefix + "_update", kwargs={'pk': obj.id})
         else:
-            item = reverse(space + ':' + prefix + "_create")
-        items = path.split(":")
-        push(items, item)
-        items.append(item)
-        path = ":".join(items)
+            segment = reverse(space + ':' + prefix + "_create")
+
+        segments = path.split(":")
+        push(segments, segment)
+        segments.append(segment)
+        path = ":".join(segments)
 
     segments = path.split(':')
     context['back'] = segments[-2] if len(segments) > 1 else ''
@@ -418,6 +456,10 @@ def get_path(request, context, obj, prefix, space=settings.DEFAULT_SPACE):
     return action
 
 
+def pop(path):
+    return path.rsplit(':', 1)[0]
+
+
 def pop_path(request):
     path = request.POST['path'] if 'path' in request.POST else ''
     return path.rsplit(':', 1)[0]
