@@ -11,7 +11,7 @@ class ConditionTables(TableView):
             TableColumn('label', "Libellé"),
             TableColumn('criteria', "Critère"),
             TableColumn('value', "Valeur")
-        ], path='django:conditions', search=True)
+        ], path='django/conditions', search=True)
         self.update = 'django:condition_update'
         self.create = 'django:condition_create'
 
