@@ -223,6 +223,13 @@ def grid_form(request, grid, read_only=False):
         if 'sort' in request.GET:
             sort = request.GET['sort']
 
+        invalid_sort = True
+        for column in columns:
+            if column.label == sort:
+                invalid_sort = False
+        if invalid_sort:
+            sort = None
+
         request.session[full_name] = context['sort'] = sort
 
         if rows and sort and len(sort_columns) == 0:
@@ -258,7 +265,12 @@ def grid_form(request, grid, read_only=False):
                 output = report.output if hasattr(report, 'output') else grid.table + ".pdf"
                 return print_report(report.build(rows), output)
 
-    context['rows'] = paginate(request, context, rows) if rows else None
+    try:
+        context['rows'] = paginate(request, context, rows) if rows else None
+    except Exception as ex:
+        rows = None
+        context['rows'] = rows
+        context['error'] = ex
     context['count'] = rows.count() if rows else 0
 
     context['group_by'] = grid.group_by if grid else None
