@@ -23,7 +23,7 @@ class LogTable(TableView):
             TableColumn('user', "Utilisateur"),
             TableColumn('model', "Table"),
             TableColumn('action', "Action")
-        ], path='django:logs', search=True, sort='date_desc')
+        ], path='django/logs', search=True, sort='date_desc')
         self.update = 'django:log_update'
         self.buttons = [
             TableButton("Calculer", "send('compute')")
@@ -80,7 +80,7 @@ def log_update(request, pk):
 
     context['navigate'] = can_navigate(request, context, '/logs') and log
     if context['navigate']:
-        logs = get_logs(request, context)
+        logs = LogTable().get_rows(request, context)
         navigate(request, context, logs, log.id)
 
     return render(request, 'log.html', context)
